# Generated by Django 2.2.26 on 2022-08-10 16:32

from io import StringIO

import lxml
import lxml.html
from django.db import migrations, models


def forward_title_migration(apps, schema_editor):
    TextCell = apps.get_model('data', 'TextCell')
    for cell in TextCell.objects.all():
        if not cell.text:
            continue

        parser = lxml.etree.HTMLParser()
        html_document = lxml.etree.parse(StringIO(cell.text), parser)
        root = html_document.getroot()

        if root is None:
            continue

        title_nodes = root.xpath('/html/body/h2[1]')
        if not title_nodes:
            continue

        assert len(title_nodes) == 1
        title_node = title_nodes[0]
        if len(title_node) != 0 or len(title_node.attrib) != 0:
            continue

        body = title_node.getparent()
        title = title_node.text or ''
        text = title_node.tail or ''
        text += body.text or ''
        text += ''.join([lxml.html.tostring(child).decode() for child in body[1:]])
        cell.title = title
        cell.text = text
        print(title)
        cell.save()


def reverse_title_migration(apps, schema_editor):
    TextCell = apps.get_model('data', 'TextCell')
    for cell in TextCell.objects.all():
        if cell.title:
            cell.text = f'<h2>{cell.title}</h2>{cell.text}'
        cell.save()


class Migration(migrations.Migration):

    dependencies = [
        ('data', '0057_pagesnapshot_label'),
    ]

    operations = [
        migrations.AddField(
            model_name='textcell',
            name='title',
            field=models.CharField(blank=True, max_length=150, null=True, verbose_name='Title'),
        ),
        migrations.RunPython(forward_title_migration, reverse_title_migration),
    ]
